s.linlir-function that determines the Likelihood-based Region Minimax (LRM) line(s).gen.lms(dat, p = 0.5, bet, epsilon = 0, k.u = 0)nx4 data.frame containing the imprecise data of the analyzed variables. Columns 1 and 2 correspond to the interval-valued observations of the regressor variable, columns 3 and 4 to those of the dependent variable.k.u is calculated on the basis of p, bet and epsilon.s.linlir,
kl.ku,
undom.para