s.linlir(dat.idf, var=NULL, p=0.5, bet, epsilon=0, a.grid=100)
"print"(x, ...)
"summary"(object, ...)
"plot"(x, y=NULL, ..., typ, para.typ="polygon", b.grid=500, nb.func=1000, seed.func=NULL, pl.lrm=TRUE, pl.band=FALSE, lrm.col="blue", pl.dat=FALSE, pl.dat.typ="hist", k.x=1, k.y=1, inf.margin=10, p.cex=1, col.lev=15, plot.grid=FALSE, x.adj=0.5, x.padj=3, y.las=0, y.adj=1, y.padj=0,x.lim=c(0,0), y.lim=c(0,0), x.lab=" ", y.lab=" ")idf-object to be analyzed.
idf-object to be analyzed.
undom.para determining the undominated parameter combinations.
plot and print. Here x is the s.linlir-object to be plotted or printed.
plot, print and summary: Other parameters.
s.linlir-object to be summarized.
plot. Here y=NULL.
"para": plot undominated parameter set, "lrm": plot LRM regression line(s), "func": plot undominated regression functions.
typ="para" are "polygon" (default) or "points" (approximation).
typ="para" with default option "polygon". b.grid is the number of points over the range of slope values at which the corresponding undominated intercept values are displayed.
typ="func".typ="func". (Optional)
typ=c("para","func"). If pl.lrm=TRUE (default), the LRM regression line(s) is highlighted in the plot.
typ=c("para","func") with option pl.lrm=TRUE.
typ="func". If pl.band=TRUE, the band(s) around the LRM regression line(s) is added to the plot.
typ=c("lrm","func"). If pl.dat=TRUE, the data are plotted in the background of the plot.
"hist": plot 2-dim. histogram (default) and "draft".
k.x is the step width along the abscissa.
k.y is the step width along the ordinate.
pl.dat.typ="draft". inf.margin is the number of steps that the infinite observations are drawn beyond the limits of the plot.
pl.dat.typ="draft". p.cex is the point size to fill the rectangles with grey color.
pl.dat.typ="hist" indicating the number of different grey levels in the 2-dim. histogram.
pl.dat.typ="hist". If plot.grid=TRUE dashed lines are added to the plot to indicate the location of the interval endpoints. This is particularly useful for categorized data.
y.las=1 will turn the axis labels and the text in reading direction.
y.adj regulates the position of the text for the ordinate in reading direction, i.e. if y.las=0 it sets the vertical position and if y.las=1 the horizontal position.
y.padj regulates the position of the text for the ordinate orthogonal to the reading direction, i.e. if y.las=0 it sets the horizontal position and if y.las=1 the vertical position.
nx4 data.frame containing the imprecise data of the analyzed variables. Columns 1 and 2 correspond to the interval-valued observations of the regressor variable, columns 3 and 4 to those of the dependent variable.s.linlir.A. Wiencierz, M. Cattaneo (2012b). An exact algorithm for Likelihood-based Imprecise Regression in the case of simple linear regression with interval data. In: R. Kruse et al. (Eds.). Advances in Intelligent Systems and Computing. Vol. 190. Springer. pp. 293-301.
M. Cattaneo, A. Wiencierz (2012a). Likelihood-based Imprecise Regression. International Journal of Approximate Reasoning. Vol. 53. pp. 1137-1154.
idf.create,
gen.lms,
kl.ku,
undom.para
data('toy.smps')
toy.idf <- idf.create(toy.smps, var.labels=c("x","y"))
test <- s.linlir(toy.idf, bet=0.5)
test
summary(test)
plot(test, typ="para", x.adj=0.7, y.las=1, y.adj=6, y.padj=-3)
plot(test, typ="func", pl.lrm=FALSE, x.adj=0.7, y.adj=0.7, y.padj=-3)
plot(test, typ="lrm", lrm.col="red", pl.band=TRUE, pl.dat=TRUE, pl.dat.typ="draft",k.x=10, k.y=10, y.las=1, y.adj=6)
Run the code above in your browser using DataLab